pecos.qeclib.qubit
==================

.. automodule:: pecos.qeclib.qubit



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.qubit.measures
   pecos.qeclib.qubit.preps
   pecos.qeclib.qubit.qgate_base
   pecos.qeclib.qubit.rots
   pecos.qeclib.qubit.sq_face_rots
   pecos.qeclib.qubit.sq_hadamards
   pecos.qeclib.qubit.sq_noncliffords
   pecos.qeclib.qubit.sq_paulis
   pecos.qeclib.qubit.sq_sqrt_paulis
   pecos.qeclib.qubit.tq_cliffords
   pecos.qeclib.qubit.tq_noncliffords
